@@ -29,7 +29,6 @@ var group__pw__keys =
     [ "PW_KEY_LOOP_CLASS", "group__pw__keys.html#ga4836fc421baa5271b4094b1922f64412", null ],
     [ "PW_KEY_LOOP_RT_PRIO", "group__pw__keys.html#ga3ea2f59d846e7a2d94ebd1c5b7c1dd92", null ],
     [ "PW_KEY_LOOP_CANCEL", "group__pw__keys.html#ga9ad7c7f1ed3d5c175e58f1c328d75825", null ],
-    [ "PW_KEY_LOOP_RETRY_TIMEOUT", "group__pw__keys.html#ga4a33a25ae6f09a40a95eefd46c2a5ee4", null ],
     [ "PW_KEY_CONTEXT_PROFILE_MODULES", "group__pw__keys.html#ga2b3f6a3b030fd27d17482e601c22be3b", null ],
     [ "PW_KEY_USER_NAME", "group__pw__keys.html#ga42bba61b82c004dd909c1796633e936b", null ],
     [ "PW_KEY_HOST_NAME", "group__pw__keys.html#ga9530cacf53a11083543fc8b0076d8b4b", null ],
@@ -188,5 +187,6 @@ var group__pw__keys =
     [ "PW_KEY_VIDEO_SIZE", "group__pw__keys.html#gacc4d098e86d0be0bfe469604c07f4009", null ],
     [ "PW_KEY_TARGET_OBJECT", "group__pw__keys.html#ga7983296afaca4d7edac60714fa92565b", null ],
     [ "PW_KEY_PRIORITY_MASTER", "group__pw__keys.html#ga1872a5fd956b36a36793554d22d99c6c", null ],
-    [ "PW_KEY_NODE_TARGET", "group__pw__keys.html#ga33441b02b8e14e14451272c2b497a5c9", null ]
+    [ "PW_KEY_NODE_TARGET", "group__pw__keys.html#ga33441b02b8e14e14451272c2b497a5c9", null ],
+    [ "PW_KEY_LOOP_RETRY_TIMEOUT", "group__pw__keys.html#ga4a33a25ae6f09a40a95eefd46c2a5ee4", null ]
 ];
\ No newline at end of file
