@@ -65,8 +65,8 @@ var NAVTREEINDEX =
 "structpw__impl__link__events.html",
 "structpw__proxy__events.html",
 "structspa__debug__log__ctx.html",
-"structspa__loop__control__hooks.html#a94545cf994d47a1acc84437e5c357141",
-"structspa__rectangle.html#a7510157f1ac054a3dc70c0c6d49083ad"
+"structspa__loop__control__hooks.html#a129526ea88e29db103f01666a32c2d20",
+"structspa__rectangle.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
