@@ -183,9 +183,11 @@ var NAVTREEINDEX20 =
 "structspa__io__segment.html#af9ec3a1565e77b1ad781376b758b58c3":[8,7,6,15,0],
 "structspa__io__segment__bar.html":[8,7,6,13],
 "structspa__io__segment__bar.html#a212f71e2e8b5587d48f4a71151ebdda5":[8,7,6,13,5],
-"structspa__io__segment__bar.html#a23933e48afa26296c4b2c2df6470bb12":[8,7,6,13,6],
+"structspa__io__segment__bar.html#a34df6bc077aed465af23d8b5b8d74a85":[8,7,6,13,8],
 "structspa__io__segment__bar.html#a5398027b6c636c287b2df47239b6b9e3":[8,7,6,13,4],
 "structspa__io__segment__bar.html#a65f1a61b7161bc2ddfb12e2bec1c51d3":[8,7,6,13,3],
+"structspa__io__segment__bar.html#a7c4acf7c0d30df734669355189d0879f":[8,7,6,13,7],
+"structspa__io__segment__bar.html#ad1c1cb6cda52db4b3ffbb4dbee804bb0":[8,7,6,13,6],
 "structspa__io__segment__bar.html#ad6d079e00b9b7428ab66c7f7fc5e0a5e":[8,7,6,13,1],
 "structspa__io__segment__bar.html#af6cb2a9476c6fda23897ed5d45b3f2d4":[8,7,6,13,2],
 "structspa__io__segment__bar.html#afaad39c0e35dbd2e4fc075a93914341f":[8,7,6,13,0],
@@ -247,7 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__loop.html#a6cd472082b361bc90f66c41b0dccea96":[8,7,9,4,1,0],
 "structspa__loop__control.html":[8,7,9,4,2],
 "structspa__loop__control.html#a392f811fbacb15de863fc0265031050f":[8,7,9,4,2,0],
-"structspa__loop__control__hooks.html":[8,7,9,4,6],
-"structspa__loop__control__hooks.html#a129526ea88e29db103f01666a32c2d20":[8,7,9,4,6,1],
-"structspa__loop__control__hooks.html#a1d60078aab0c143a082ab30e91151dd2":[8,7,9,4,6,0]
+"structspa__loop__control__hooks.html":[8,7,9,4,6]
 };
