@@ -1,5 +1,9 @@
 var NAVTREEINDEX22 =
 {
+"structspa__rectangle.html":[8,7,8,1,1],
+"structspa__rectangle.html#a6104eab08e11a0f5f658a5ffd1878068":[8,7,8,1,1,0],
+"structspa__rectangle.html#a7510157f1ac054a3dc70c0c6d49083ad":[8,7,8,1,1,1],
+"structspa__region.html":[8,7,8,1,3],
 "structspa__region.html#a848acf4be0e186e985eafc3b858f0079":[8,7,8,1,3,0],
 "structspa__region.html#aac81486ee3a2fbbd52534691bc740f63":[8,7,8,1,3,1],
 "structspa__result__device__params.html":[8,7,4,6],
